@@ -1513,8 +1513,8 @@ def raw_vt_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1:
         f2 = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
                                                i, delta, molecule_depth, svt)\
                     * elastic_omega_g_only_vss(g, deg, -gsso2)
-        return mult * (gssc1 * ((constants.k * T) ** (-gsso1)) * integrate.quad(f1, 0, np.inf)[0] +
-                       gssc2 * ((constants.k * T) ** (-gsso2)) * integrate.quad(f2, 0, np.inf)[0])
+        return mult * (gssc1 * ((constants.k * T) ** gsso1) * integrate.quad(f1, 0, np.inf)[0] +
+                       gssc2 * ((constants.k * T) ** gsso2) * integrate.quad(f2, 0, np.inf)[0])
     else:
         raise KineticlibError('VT transition with no change in vibrational level specified')
 
@@ -1737,8 +1737,8 @@ def raw_vv_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1:
                                                i, k, i_delta, svv) * elastic_omega_g_only_vss(g, deg, -gsso1)
         f2 = lambda g: prob.vv_prob_g_only_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2,
                                                i, k, i_delta, svv) * elastic_omega_g_only_vss(g, deg, -gsso2)
-        return mult * (gssc1 * ((constants.k * T) ** (-gsso1)) * integrate.quad(f1, 0, np.inf)[0] +
-                       gssc2 * ((constants.k * T) ** (-gsso2)) * integrate.quad(f2, 0, np.inf)[0])
+        return mult * (gssc1 * ((constants.k * T) ** gsso1) * integrate.quad(f1, 0, np.inf)[0] +
+                       gssc2 * ((constants.k * T) ** gsso2) * integrate.quad(f2, 0, np.inf)[0])
     else:
         raise KineticlibError('VV transition with no change in vibrational level specified')
 
