@@ -14,8 +14,8 @@ from .particles import Particle, Molecule
 import numpy as np
 
 
-def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
-                     n: float, infcoll: float, model: str='VSS') -> float:
+def rot_rel_time_vss(T: float, idata: np.ndarray, molecule: Molecule,
+                     n: float,  model: str='VSS') -> float:
     """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula
 
     Parameters
@@ -28,8 +28,6 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
         the molecule for which the rotational relaxation time is being calculated
     n : float
         the numeric density of the mixture
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
     model : str
         the interaction model to be used, possible values:
             * 'VSS' (Variable Soft Sphere model)
@@ -43,11 +41,11 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: Molecule,
     float
         Rotational relaxation time
     """
-    return raw_rot_rel_time_VSS(T, idata[0], molecule.LJe, idata[9], idata[10], idata[11], idata[12],
-                                molecule.mass, n, infcoll, model)
+    return raw_rot_rel_time_vss(T, idata[0], molecule.LJe, idata[9], idata[10], idata[11], idata[12],
+                                molecule.mass, n, molecule.infcoll, model)
 
 
-def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infcoll: float,
+def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float,
                  model: str='ESA', Zr_model: str='VSS') -> float:
     """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral
 
@@ -61,17 +59,16 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infc
         the molecule for which the rotational relaxation time is being calculated
     n : float
         the numeric density of the mixture
-    infcoll : float
-        the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
     model : str
         the interaction model to be used to calculate the :math:`\\Omega^{(2,2)}` integral, possible values:
-            * 'IPL' (Inverse Power Law potential)
+            * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
+            * 'BM' (Inverse Power Law potential)
             * 'LJ' (Lennard-Jones potential)
+            * 'MLJ' (Modified Lennard-Jones model)
             * 'RS' (Rigid Sphere model)
             * 'VSS' (Variable Soft Sphere model)
             * 'Switch' (returns the result for the Lennard-Jones model when :math:`T / \\varepsilon_{cd} < 10`
               and for the IPL potential otherwise)
-            * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
 
         defaults to 'ESA'
     Zr_model : str
@@ -88,12 +85,12 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infc
         Rotational relaxation time
     """
     return raw_rot_rel_time(omega(T, 2, 2, idata, model=model, nokt=False), n,
-                            raw_Zr(T, idata[0], molecule.LJe, idata[10], idata[11], idata[12], molecule.mass, infcoll,
-                                   Zr_model))
+                            raw_Zr(T, idata[0], molecule.LJe, idata[10], idata[11], idata[12], molecule.mass,
+                                   molecule.infcoll, Zr_model))
 
 
 def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: Particle, n: float,
-                     model: str='VSS') -> float:
+                     model: str='VSS', prob_model: str='EQ') -> float:
     """Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference)
 
@@ -119,6 +116,12 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: P
             * 'VSS' (Variable Soft Sphere model)
 
         defaults to 'VSS'
+    prob_model : str, optional
+        the model to be used for the probability of rotational transitions, possible value:
+
+            * 'EQ' - all transitions are considered equiprobable
+
+        defaults to 'EQ'
 
     Returns
     -------
@@ -126,18 +129,21 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: P
         Rotational relaxation time
     """
     if isinstance(partner, Molecule):
-        return raw_rot_rel_time_def_molecule_partner(T, idata[1], idata[0], idata[9], idata[10],
-                                                     molecule.Z_rot(T), partner.Z_rot(T),
-                                                     molecule.rot_symmetry, partner.rot_symmetry, molecule.rot_const,
-                                                     partner.rot_const, molecule.num_rot, partner.num_rot,
-                                                     molecule.name == partner.name, n, model)
+        if partner.name == molecule.name:
+            return 0.25 / (n * cs.elastic_integral(T, 0, idata, model, False)
+                           * (cs.dE_rot_sq(T, idata, molecule, False, model, prob_model)
+                           + cs.dE_rot_c_dE_rot_d(T, idata, molecule, partner, False, model, prob_model)))
+        else:
+            return 0.25 / (n * cs.elastic_integral(T, 0, idata, model, False)
+                           * (cs.dE_rot_dE_rot_full(T, idata, molecule, partner, False, model, prob_model)
+                           + cs.dE_rot_dE_rot_full(T, idata, partner, molecule, False, model, prob_model)))
+
     else:
-        return raw_rot_rel_time_def_atom_partner(T, idata[1], idata[0], idata[9], idata[10],
-                                                 molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const,
-                                                 molecule.num_rot, n, model)
+        return 0.25 / (n * cs.elastic_integral(T, 0, idata, model, False)
+                       * cs.dE_rot_sq(T, idata, molecule, False, model, prob_model))
 
 
-def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: str='VSS') -> float:
+def Zr(T: float, idata: np.ndarray, molecule: Molecule, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models
 
     Parameters
@@ -163,7 +169,7 @@ def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: s
     float
         Amount of collisions needed to reach rotational equilibrium
     """
-    return raw_Zr(T, idata[0], molecule.LJe, idata[10], idata[11], idata[12], molecule.mass, infcoll, model)
+    return raw_Zr(T, idata[0], molecule.LJe, idata[10], idata[11], idata[12], molecule.mass, molecule.infcoll, model)
 
 
 def millikan_white(T: float, idata: np.ndarray, molecule: Molecule, p: float) -> float:
@@ -188,7 +194,7 @@ def millikan_white(T: float, idata: np.ndarray, molecule: Molecule, p: float) ->
     return raw_millikan_white(T, idata[0], molecule.hvc, p)
 
 
-def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: float, vsso: float, vssc_deflection: float,
+def raw_rot_rel_time_vss(T: float, collision_mass: float, eps: float, vssc: float, vsso: float, vssc_deflection: float,
                          vsso_deflection: float, mass: float, n: float, infcoll: float, model: str='VSS') -> float:
     """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula,
     *raw* version
@@ -255,130 +261,6 @@ def raw_rot_rel_time(omega_integral: float, n: float, Zr: float) -> float:
     return 0.15625 * constants.pi * Zr / (n * omega_integral)  # 0.15625 is 5 / 32
 
 
-def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
-                                          Z_rot1: float, Z_rot2: float,
-                                          molecule_rot_symmetry1: float, molecule_rot_symmetry2: float,
-                                          molecule_rot_const1: float, molecule_rot_const2: float,
-                                          molecule_num_rot1: int, molecule_num_rot2: int, same_partner: bool,
-                                          n: float, model: str='VSS') -> float:
-    """Calculates the rotational relaxation time using the definition (through the averaging of the squared
-    rotational energy difference) for the case when the partner is a molecule, *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    sigma : float
-        the collision diameter :math:`\\sigma_{cd}`
-    mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    vssc : float
-        the VSS potential :math:`C` parameter
-    vsso : float
-        the VSS potential :math:`\\omega` parameter
-    Z_rot1 : float
-        the value of the rotational partition function of the first molecule
-    Z_rot2 : float
-        the value of the rotational partition function of the second molecule
-    molecule_rot_symmetry1 : float
-        should equal 2.0 if the first molecule is homonuclear and 1.0 otherwise
-    molecule_rot_symmetry2 : float
-        should equal 2.0 if the second molecule is homonuclear and 1.0 otherwise
-    molecule_rot_const1 : float
-        the quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
-        inertia of the first molecule
-    molecule_rot_const2 : float
-        the quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
-        inertia of the second molecule
-    molecule_num_rot1 : int
-        the amount of rotational levels in the first molecule
-    molecule_num_rot2 : int
-        the amount of rotational levels in the second molecule
-    same_partner : bool
-        if the collision partner is of the same molecular species, should be set to ``True``, otherwise should be
-        set to ``False``
-    n : float
-        the numeric density of the mixture
-    model : str, optional
-        the elastic crosssection model to be used, possible values:
-
-            * 'RS' (Rigid Sphere model)
-            * 'VSS' (Variable Soft Sphere model)
-
-        defaults to 'VSS'
-
-    Returns
-    -------
-    float
-        Rotational relaxation time
-    """
-
-    if same_partner:
-        return 0.5 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, model, False)
-                      * (2 * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1,
-                                              molecule_rot_const1, molecule_num_rot1, False, model, False)
-                         + 2 * cs.raw_dE_rot_c_dE_rot_d(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2,
-                                                        molecule_rot_symmetry1, molecule_rot_symmetry2,
-                                                        molecule_rot_const1, molecule_rot_const2,
-                                                        molecule_num_rot1, molecule_num_rot2, False, model, False)))
-    else:
-        return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, model, False)
-                       * (cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2, molecule_rot_symmetry1,
-                                                    molecule_rot_symmetry2, molecule_rot_const1, molecule_rot_const2,
-                                                    molecule_num_rot1, molecule_num_rot2, False, model, False)
-                       + cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot2, Z_rot1, molecule_rot_symmetry2,
-                                                   molecule_rot_symmetry1, molecule_rot_const2, molecule_rot_const1,
-                                                   molecule_num_rot2, molecule_num_rot1, False, model, False)))
-        
-        
-def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
-                                      Z_rot: float, molecule_rot_symmetry: float,
-                                      molecule_rot_const: float, molecule_num_rot: int, n: float,
-                                      model: str='VSS') -> float:
-    """Calculates the rotational relaxation time using the definition (through the averaging of the squared
-    rotational energy difference) for the case when the partner is an atom, *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    sigma : float
-        the collision diameter :math:`\\sigma_{cd}`
-    mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    vssc : float
-        the elastic crosssection VSS potential :math:`C` parameter
-    vsso : float
-        the elastic crosssection VSS potential :math:`\\omega` parameter
-    Z_rot : float
-        the value of the rotational partition function of the molecule
-    molecule_rot_symmetry : float
-        should equal 2.0 if the molecule is homonuclear and 1.0 otherwise
-    molecule_rot_const : float
-        the quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
-        inertia of the molecule
-    molecule_num_rot : int
-        the amount of rotational levels in the molecule
-    n : float
-        the numeric density of the mixture
-    model : str, optional
-        the elastic crosssection model to be used, possible values:
-
-            * 'RS' (Rigid Sphere model)
-            * 'VSS' (Variable Soft Sphere model)
-
-        defaults to 'VSS'
-
-    Returns
-    -------
-    float
-        Rotational relaxation time
-    """
-    return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, model, False)
-                   * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot, molecule_rot_symmetry,
-                                      molecule_rot_const, molecule_num_rot, False, model, False))
-
-
 def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflection: float, vsso_deflection: float,
            mass: float, infcoll: float, model: str='VSS') -> float:
     """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models,
