@@ -85,9 +85,8 @@ def wt_poly_norm_oneT(T: float, molecule: MoleculeOneT) -> float:
     float
         The square of the "norm" of the Waldman Trubenbacher polynomial
     """
-    return molecule.avg_vibr_energy_sq(T, False) + molecule.avg_rot_energy_sq(T, False)\
-                                                 + 2 * molecule.avg_vibr_energy(T, False)\
-                                                     * molecule.avg_rot_energy(T, False)
+    return molecule.avg_vibr_energy_sq(T, False) - (molecule.avg_vibr_energy(T, False) ** 2)\
+           + molecule.avg_rot_energy_sq(T, False) - (molecule.avg_rot_energy(T, False) ** 2)
 
 
 def wt_simple_avg(T: float, T1: float, molecule: MoleculeMultiT, F: float=0.0) -> float:
